import { useCallback, useMemo } from "react"
import { ShipProps } from "../interfaces/frontend"
import { useGameProps } from "./useGameProps"
import useIndex from "./useIndex"

function useShips() {
  const gameProps = useGameProps()
  const { selfIndex } = useIndex()

  const ships = useMemo(
    () =>
      gameProps.payload?.users.find((e) => e?.index === selfIndex)?.ships ?? [],
    [gameProps.payload?.users, selfIndex],
  )
  const setShips = useCallback(
    (ships: ShipProps[]) => gameProps.setShips(ships, selfIndex),
    [gameProps, selfIndex],
  )
  const removeShip = useCallback(
    (ship: ShipProps) => gameProps.removeShip(ship, selfIndex),
    [gameProps, selfIndex],
  )

  return { ships, setShips, removeShip }
}

export default useShips
